/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  main.c - c file for main function
 *  DRV8434S-EVM_FIRMWARE
 *  10/28/2020
 *  updated 01/20/2022
 *
 ******************************************************************************/
#include <drv8434/include/drv8434.h>
#include "msp430.h"
#include "SPI.h"
#include <stepper.h>
#include "Serial_Cmd_Monitor.h"

// Main
int gErrCnt = 0;

int main(void)
{
    mcu_init();                                       // Initialize MCU peripherals
    drv8434s_init();                                  // Device ID and version configurations

    // Serial protocol between GUI USB and MCU UART
    __bis_SR_register(GIE);
    ClearBufferRelatedParam();                        // GUI Composer Monitor Initialization
    stepper_Init();                                   // Stepper routine initialization

    while (1)
    {

        UpdateDeviceControls();                       // read the GUI values and pass to device
        UpdateGUIControls();                          // read device values and pass to GUI
        UpdateSpeed();                                // control the motor based on info captured above
        UpdateGUI_Register();                         // registers read and write routines

        capture_stall_info_cnt++;
        if (capture_stall_info_cnt == gStepper_Obj.StallSampleTime)
        {
            capture_stall_info_cnt = 0;
            UpdateStallInfo();                        // update TRQ_COUNT to DAC0 output for analog monitoring and logging
        }

        SetMotorParameters();
        DetermineNextAction();

        __bis_SR_register(LPM0_bits + GIE);           // Enter LPM0
    }
}

// Watchdog Timer Interrupt Service Routine. Status LED timing derived from the watchdog timer
#pragma vector=WDT_VECTOR
__interrupt void WatchDog_Timer(void)
{
    LED_TOGGLE_CNT++;
    __bic_SR_register_on_exit(LPM0_bits);             // Clear LPM0 bits
}

