/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  stepper_ISR.h - Declaration file for functions and global variables related to stepper control
 *  DRV8889_EVM_FIRMWARE
 *  10/28/2020
 *  updated 01/20/2022
 *
 ******************************************************************************/

#include <drv8434/include/drv8434.h>
#include <msp430.h>
#include "stepper.h"
#include <SPI.h>
#include <intrinsics.h>

#pragma vector= DAC12_VECTOR, DMA_VECTOR, USCIAB1TX_VECTOR, USCIAB1RX_VECTOR, \
                PORT1_VECTOR, PORT2_VECTOR,ADC12_VECTOR, COMPARATORA_VECTOR, \
                TIMERA1_VECTOR, TIMERB1_VECTOR, NMI_VECTOR
__interrupt void Trap_ISR(void)
{
}

#pragma vector=TIMERB0_VECTOR
__interrupt void TimerB0(void)
{
    enable_TAInterrupt = true;
    // disable interrupts if target speed is reached
    if (((gStepper_Obj.AccelerateState == RUN)
            && (gStepper_Obj.RUN_STEPPER == true))
    // but keep interrupts active during STALL learn
            &&
            ((gStepper_Obj.StallState == DISABLED) || (gStepper_Obj.StallState == SUCCESS))
            )
    {
    // disable timer A interrupt
        enable_TAInterrupt = false;
    }
    UpdateMotorParameters = true;
}

#pragma vector=TIMERA0_VECTOR
__interrupt void TimerA0(void)
{

    // Reload the timers
    TACCR0 = SteppingRateTMR;                         //
    TACCR1 = SteppingRateTMR >> 1;                    // set at 50% duty cycle
    UpdateNextAction = true;
    // check to stop timers if counting steps
    if (MoveSteps)                                    // if manual advance count steps
    {                                                 // when counts completed
        tmpStepsToMove++;
    // stop interrupts here to avoid latency
        if (tmpStepsToMove >= StepsToMove)            // stop here when equal
        {
            TACTL &= ~MC_3;                           // Stop timerA
            TBCTL &= ~MC_3;                           // Stop timerB
        }
    }
}
